<?php

/*
  +---------------------------------------------------------------------------+
  | Revive Adserver                                                           |
  | http://www.revive-adserver.com                                            |
  |                                                                           |
  | Copyright: See the COPYRIGHT.txt file.                                    |
  | License: GPLv2 or later, see the LICENSE.txt file.                        |
  +---------------------------------------------------------------------------+
 */

// Set text direction and characterset


// Date & time configuration

// Formats used by PEAR Spreadsheet_Excel_Writer packate

/* ------------------------------------------------------- */
/* Translations                                          */
/* ------------------------------------------------------- */

$GLOBALS['strHelp'] = "Cymorth";
$GLOBALS['strStartOver'] = "Cychwyn eto";
$GLOBALS['strShortcuts'] = "Llwybrau Byr";
$GLOBALS['strActions'] = "Gweithred";
$GLOBALS['strAdminstration'] = "Rhestren";
$GLOBALS['strMaintenance'] = "Cynnal";
$GLOBALS['strProbability'] = "Tebygolrwydd";
$GLOBALS['strInvocationcode'] = "Cod Actifadu";
$GLOBALS['strBasicInformation'] = "Gwybodaeth Sylfaenol";
$GLOBALS['strAppendTrackerCode'] = "Atodi Cod Traciwr";
$GLOBALS['strOverview'] = "Trosolwg";
$GLOBALS['strSearch'] = "Chwilio";
$GLOBALS['strDetails'] = "Manylion";
$GLOBALS['strCheckForUpdates'] = "Gwirio am Ddiweddariadau";
$GLOBALS['strCompact'] = "Cywasgu";
$GLOBALS['strUser'] = "Defnyddiwr";
$GLOBALS['strDuplicate'] = "Dyblygu";
$GLOBALS['strMoveTo'] = "Symud i";
$GLOBALS['strDelete'] = "Dileu";
$GLOBALS['strActivate'] = "Ysgogi";
$GLOBALS['strConvert'] = "Trosi";
$GLOBALS['strRefresh'] = "Ail-lwytho";
$GLOBALS['strSaveChanges'] = "Cadw newidiadau";
$GLOBALS['strUp'] = "I fyny";
$GLOBALS['strDown'] = "I lawr";
$GLOBALS['strSave'] = "Cadw";
$GLOBALS['strCancel'] = "Canslo";
$GLOBALS['strPrevious'] = "Blaenorol";
$GLOBALS['strNext'] = "Nesaf";
$GLOBALS['strYes'] = "Iawn";
$GLOBALS['strNo'] = "Na";
$GLOBALS['strNone'] = "Dim";
$GLOBALS['strCustom'] = "Addasu";
$GLOBALS['strDefault'] = "Rhagosodiad";
$GLOBALS['strUnlimited'] = "Diderfyn";
$GLOBALS['strUntitled'] = "Di-deitl";
$GLOBALS['strAll'] = "popeth";
$GLOBALS['strAverage'] = "Cyfartaledd";
$GLOBALS['strOverall'] = "Cyffredinol";
$GLOBALS['strTotal'] = "Cyfanswm";
$GLOBALS['strTo'] = "i";
$GLOBALS['strLinkedTo'] = "wedi cysylltu â";
$GLOBALS['strDaysLeft'] = "Dyddiau ar ôl";
$GLOBALS['strCheckAllNone'] = "Gwirio popeth / dim";
$GLOBALS['strExpandAll'] = "<u>E</u>hangu popeth";
$GLOBALS['strCollapseAll'] = "<u>C</u>ywasgu popeth";
$GLOBALS['strShowAll'] = "Dangos popeth";
$GLOBALS['strNoAdminInterface'] = "Mae'r sgrin gweinyddu wedi cael ei ddiffodd ar gyfer gwaith cynnal a chadw.  Ni fydd hyn yn effeithio ar eich ymgyrchoedd.";
$GLOBALS['strFieldContainsErrors'] = "Mae'r meysydd canlynol yn cynnwys gwallau:";
$GLOBALS['strFieldFixBeforeContinue1'] = "Cyn parhau, bydd angen i chi";
$GLOBALS['strFieldFixBeforeContinue2'] = "gywiro'r gwallau yma.";
$GLOBALS['strMiscellaneous'] = "Amrywiol";
$GLOBALS['strCollectedAllStats'] = "Holl ystadegau";
$GLOBALS['strCollectedToday'] = "Heddiw";
$GLOBALS['strCollectedYesterday'] = "Ddoe";
$GLOBALS['strCollectedThisWeek'] = "Yr wythnos hon";
$GLOBALS['strCollectedLastWeek'] = "Wythnos diwethaf";
$GLOBALS['strCollectedThisMonth'] = "Y mis hwn";
$GLOBALS['strCollectedLastMonth'] = "Mis diwethaf";
$GLOBALS['strCollectedLast7Days'] = "7 niwrnod diwethaf";
$GLOBALS['strCollectedSpecificDates'] = "Dyddiadau penodol";
$GLOBALS['strWarning'] = "Rhybudd";
$GLOBALS['strNotice'] = "Hysbysiad";

// Dashboard
// Dashboard Errors

// Priority
$GLOBALS['strPriority'] = "Blaenoriaeth";
$GLOBALS['strPriorityLevel'] = "Lefel blaenoriaeth";
$GLOBALS['strCapping'] = "Terfyn Uchaf";

// Properties
$GLOBALS['strName'] = "Enw";
$GLOBALS['strSize'] = "Maint";
$GLOBALS['strWidth'] = "Lled";
$GLOBALS['strHeight'] = "Uchder";
$GLOBALS['strTarget'] = "Targed";
$GLOBALS['strLanguage'] = "Iaith";
$GLOBALS['strDescription'] = "Disgrifiad";
$GLOBALS['strVariables'] = "Newidynnau";
$GLOBALS['strComments'] = "Sylwadau";

// User access
$GLOBALS['strLinkUserHelpUser'] = "Enw Defnyddiwr";

// Login & Permissions
$GLOBALS['strUserProperties'] = "Priodweddau Baner";
$GLOBALS['strAuthentification'] = "Dilysiad ";
$GLOBALS['strWelcomeTo'] = "Croeso i";
$GLOBALS['strEnterUsername'] = "Rhowch eich enw defnyddiwr a'ch cyfrinair i fewngofnodi";
$GLOBALS['strEnterBoth'] = "Rhowch eich enw defnyddiwr a'ch cyfrinair os gwelwch yn dda";
$GLOBALS['strEnableCookies'] = "Rhaid i chi alluogi cwcis cyn bod modd i chi ddefnyddio {$PRODUCT_NAME}";
$GLOBALS['strLogin'] = "Mewngofnodi";
$GLOBALS['strLogout'] = "Allgofnodi";
$GLOBALS['strUsername'] = "Enw Defnyddiwr";
$GLOBALS['strPassword'] = "Cyfrinair";
$GLOBALS['strPasswordRepeat'] = "Ailadroddwch y cyfrinair";
$GLOBALS['strAccessDenied'] = "Gwadwyd mynediad";
$GLOBALS['strUsernameOrPasswordWrong'] = "Nid oedd yr enw defnyddiwr na'r/neu'r cyfrinair yn gywir. Rhowch gynnig arall arni.";
$GLOBALS['strPasswordWrong'] = "Nid yw'r cyfrinair yn gywir";
$GLOBALS['strDuplicateClientName'] = "Mae'r enw defnyddiwr yn bodoli eisoes, defnyddiwch enw defnyddiwr gwahanol.";
$GLOBALS['strInvalidPassword'] = "Nid yw'r cyfrinair newydd yn ddilys, defnyddiwch gyfrinair gwahanol.";
$GLOBALS['strNotSamePasswords'] = "Nid yw'r ddau gyfrinair a ddarparwyd gennych yr un peth";
$GLOBALS['strRepeatPassword'] = "Ailadroddwch y cyfrinair";

// General advertising
$GLOBALS['strRequests'] = "Ceisiadau";
$GLOBALS['strImpressions'] = "Argraffiadau";
$GLOBALS['strClicks'] = "Cliciau";
$GLOBALS['strConversions'] = "Trawsnewidiadau";
$GLOBALS['strCTR'] = "CTR";
$GLOBALS['strTotalClicks'] = "Cyfanswm Cliciau";
$GLOBALS['strTotalConversions'] = "Cyfanswm Trawsnewidiadau";
$GLOBALS['strDateTime'] = "Dyddiad Amser";
$GLOBALS['strTrackerID'] = "ID Traciwr";
$GLOBALS['strTrackerName'] = "Enw Traciwr";
$GLOBALS['strBanners'] = "Baneri";
$GLOBALS['strCampaigns'] = "Ymgyrch";
$GLOBALS['strCampaignID'] = "ID Ymgyrch";
$GLOBALS['strCampaignName'] = "Enw Ymgyrch";
$GLOBALS['strCountry'] = "Gwlad";
$GLOBALS['strStatsAction'] = "Gweithred";
$GLOBALS['strWindowDelay'] = "Oediad Ffenest";
$GLOBALS['strStatsVariables'] = "Newidynnau";

// Finance
$GLOBALS['strFinanceMT'] = "Tenantiaeth Misol";

// Time and date related
$GLOBALS['strDate'] = "Dyddiad";
$GLOBALS['strDay'] = "Diwrnod";
$GLOBALS['strDays'] = "Diwrnodau";
$GLOBALS['strWeek'] = "Wythnos";
$GLOBALS['strWeeks'] = "Wythnosau";
$GLOBALS['strSingleMonth'] = "Mis";
$GLOBALS['strMonths'] = "Misoedd";
$GLOBALS['strDayOfWeek'] = "Diwrnod yr wythnos";


if (!isset($GLOBALS['strDayFullNames'])) {
    $GLOBALS['strDayFullNames'] = [];
}
$GLOBALS['strDayFullNames'][6] = 'Dydd Sadwrn';

if (!isset($GLOBALS['strDayShortCuts'])) {
    $GLOBALS['strDayShortCuts'] = [];
}
$GLOBALS['strDayShortCuts'][6] = 'Sad';

$GLOBALS['strHour'] = "Awr";
$GLOBALS['strSeconds'] = "eiliadau";
$GLOBALS['strMinutes'] = "munudau";
$GLOBALS['strHours'] = "oriau";

// Advertiser
$GLOBALS['strClient'] = "Hysbysebwr";
$GLOBALS['strClients'] = "Hysbysebwyr";
$GLOBALS['strClientsAndCampaigns'] = "Hysbysebwyr a Ymgyrchoedd";
$GLOBALS['strAddClient'] = "Ychwanegu hysbysebwr newydd";
$GLOBALS['strClientProperties'] = "Priodweddau Hysbysebwr";
$GLOBALS['strNoClients'] = "Nid oes unrhyw hysbysebwr wedi ei ddiffinio hyd yma. Er mwyn creu ymgyrch, <a href='advertiser-edit.php'>ychwanegwch hysbysebwrnewydd</a>.";
$GLOBALS['strConfirmDeleteClient'] = "Ydych chi wir am ddileu'r hysbysebwr yma?";
$GLOBALS['strConfirmDeleteClients'] = "Ydych chi wir am ddileu'r hysbysebwr yma?";
$GLOBALS['strHideInactive'] = "Cuddio anweithredol";
$GLOBALS['strInactiveAdvertisersHidden'] = "hysbysebw(y)r anweithredol wedi cuddio";
$GLOBALS['strAdvertiserCampaigns'] = "Hysbysebwyr a Ymgyrchoedd";

// Advertisers properties
$GLOBALS['strContact'] = "Cysylltu";
$GLOBALS['strEMail'] = "Ebost";
$GLOBALS['strSendAdvertisingReport'] = "Ebostio adroddiadau trosglwyddo ymgyrch";
$GLOBALS['strNoDaysBetweenReports'] = "Nifer o ddyddiau rhwng adroddiadau trosglwyddo ymgyrch";
$GLOBALS['strSendDeactivationWarning'] = "Ebostio pan mae ymgyrch wedi ysgogi/dad-ysgogi yn awtomatig";
$GLOBALS['strAllowClientModifyBanner'] = "Caniatáu y defnyddiwr i newid ei faneri";
$GLOBALS['strAllowClientDisableBanner'] = "Caniatáu y defnyddiwr i ddad-ysgogi ei faneri";
$GLOBALS['strAllowClientActivateBanner'] = "Caniatáu y defnyddiwr i ysgogi ei faneri";
$GLOBALS['strAllowAuditTrailAccess'] = "Caniatáu i'r defnyddiwr gyrchu y trywydd archwilio";

// Campaign
$GLOBALS['strCampaign'] = "Ymgyrch";
$GLOBALS['strCampaigns'] = "Ymgyrch";
$GLOBALS['strAddCampaign'] = "Ychwanegu ymgyrch newydd";
$GLOBALS['strAddCampaign_Key'] = "Ychwanegu ymgyrch <u>n</u>ewydd";
$GLOBALS['strLinkedCampaigns'] = "Ymgyrchoedd Cysylltiedig";
$GLOBALS['strCampaignProperties'] = "Priodoleddau Ymgyrch";
$GLOBALS['strCampaignOverview'] = "Trosolwg ymgyrch";
$GLOBALS['strConfirmDeleteCampaign'] = "Ydych chi wir am ddileu yr ymgyrch yma?";
$GLOBALS['strConfirmDeleteCampaigns'] = "Ydych chi wir am ddileu yr ymgyrch yma?";
$GLOBALS['strShowParentAdvertisers'] = "Dangos hysbysebwyr rhiant";
$GLOBALS['strHideParentAdvertisers'] = "Cuddio hysbysebwyr rhiant";
$GLOBALS['strHideInactiveCampaigns'] = "Cuddio ymgyrchoedd sydd ddim yn weithredol";
$GLOBALS['strInactiveCampaignsHidden'] = "Ymgyrchoedd anweithredol wedi cuddio";
$GLOBALS['strPriorityInformation'] = "Blaenoriaeth mewn perthynas ag ymgyrchoedd eraill";
$GLOBALS['strHiddenCampaign'] = "Ymgyrch";
$GLOBALS['strHiddenAd'] = "Hysbyseb";
$GLOBALS['strHiddenAdvertiser'] = "Hysbysebwr";
$GLOBALS['strHiddenTracker'] = "Traciwr";
$GLOBALS['strHiddenWebsite'] = "Gwefan";
$GLOBALS['strHiddenZone'] = "Ardal";
$GLOBALS['strCompanionPositioning'] = "Safleoli cymar";
$GLOBALS['strSelectUnselectAll'] = "Dewis / Dad-ddewis popeth";

// Campaign-zone linking page


// Campaign properties
$GLOBALS['strLow'] = "Isel";
$GLOBALS['strHigh'] = "Uchel";
$GLOBALS['strExpirationDate'] = "Dyddiad Gorffen";
$GLOBALS['strExpirationDateComment'] = "Bydd yr ymgyrch yn gorffen ar ddiwedd y diwrnod yma";
$GLOBALS['strActivationDate'] = "Dyddiad Cychwyn";
$GLOBALS['strActivationDateComment'] = "Bydd yr ymgyrch yn cychwyn ar gychwyn y diwrnod yma";
$GLOBALS['strImpressionsRemaining'] = "Argraffiadau sy'n weddill";
$GLOBALS['strClicksRemaining'] = "Cliciau sy'n weddill";
$GLOBALS['strConversionsRemaining'] = "Trawsnewidiadau sy'n weddill";
$GLOBALS['strImpressionsBooked'] = "Argraffiadau a Archebwyd";
$GLOBALS['strClicksBooked'] = "Cliciau a Archebwyd";
$GLOBALS['strConversionsBooked'] = "Trawsnewidiadau a Archebwyd";
$GLOBALS['strAnonymous'] = "Cuddio hysbysebwr a gwefannau'r ymgyrch hwn.";
$GLOBALS['strTargetPerDay'] = "y diwrnod.";
$GLOBALS['strCampaignWarningRemnantNoWeight'] = "Mae blaenoriaeth yr ymgyrch wedi ei osod i isel,
ond mae'r pwysau wedi ei osod i sero neu nid yw wedi cael
ei nodi. Bydd hyn yn achosi bod eich ymgyrch yn
cael ei ddad-ysgogi ac ni fydd y baneri yn cael eu trosglwyddo
nes bod y pwysau yn cael ei newid i rif dilys.

Ydych chi'n siwr eich bod am barhau?";
$GLOBALS['strCampaignWarningNoTarget'] = "Mae blaenoriaeth yr ymgyrch wedi ei osod i uchel,
ond nid yw'r nifer darged o Argraffiadau wedi cael ei nodi.
Bydd hyn yn achosi bod eich ymgyrch yn cael ei ddad-ysgogi
ac ni fydd y baneri yn cael eu trosglwyddo nes bod rhif targed
dilys o Argraffiadau wedi cael ei osod.

Ydych chi'n siwr eich bod am barhau?";
$GLOBALS['strCampaignStatusPending'] = "Dan Ystyriaeth";
$GLOBALS['strCampaignStatusInactive'] = "gweithredol";
$GLOBALS['strCampaignStatusPaused'] = "Saib";
$GLOBALS['strCampaignStatusRestarted'] = "Ailgychwyn";
$GLOBALS['strCampaignStatusDeleted'] = "Dileu";
$GLOBALS['strCampaignType'] = "Enw Ymgyrch";
$GLOBALS['strType'] = "Math";
$GLOBALS['strContract'] = "Cysylltu";
$GLOBALS['strStandardContract'] = "Cysylltu";

// Tracker
$GLOBALS['strTracker'] = "Traciwr";
$GLOBALS['strTrackers'] = "Traciwr";
$GLOBALS['strAddTracker'] = "Ychwanegu traciwr newydd";
$GLOBALS['strConfirmDeleteTrackers'] = "Ydych chi wir am ddileu'r traciwr yma?";
$GLOBALS['strConfirmDeleteTracker'] = "Ydych chi wir am ddileu'r traciwr yma?";
$GLOBALS['strTrackerProperties'] = "Priodweddau Traciwr";
$GLOBALS['strDefaultStatus'] = "Rhagosodiad Statws";
$GLOBALS['strStatus'] = "Statws";
$GLOBALS['strLinkedTrackers'] = "Tracwyr Cysylltiedig";
$GLOBALS['strConversionWindow'] = "Ffenest trawsnewidiadau";
$GLOBALS['strUniqueWindow'] = "Ffenest unigryw";
$GLOBALS['strClick'] = "Clic";
$GLOBALS['strView'] = "Golwg";
$GLOBALS['strImpression'] = "Argraffiadau";
$GLOBALS['strConversionType'] = "Math trawsnewidiad";
$GLOBALS['strLinkCampaignsByDefault'] = "Cysylltwch ymgyrchoedd newydd yn ddiofyn";

// Banners (General)
$GLOBALS['strBanner'] = "Baner";
$GLOBALS['strBanners'] = "Baneri";
$GLOBALS['strAddBanner'] = "Ychwanegu baner newydd";
$GLOBALS['strAddBanner_Key'] = "Ychwanegu baner <u>n</u>ewydd";
$GLOBALS['strBannerToCampaign'] = "Eich ymgyrch";
$GLOBALS['strShowBanner'] = "Dangos baner";
$GLOBALS['strBannerProperties'] = "Priodweddau Baner";
$GLOBALS['strNoBannersAddAdvertiser'] = "Nid oes unrhyw wefan wedi cael ei ddiffinio hyd yma. I greu ardal, <a href='affiliate-edit.php'>ychwanegwch wefan newydd</a> yn gyntaf.";
$GLOBALS['strConfirmDeleteBanner'] = "Ydych chi wir am ddileu'r faner yma?";
$GLOBALS['strConfirmDeleteBanners'] = "Ydych chi wir am ddileu'r faner yma?";
$GLOBALS['strShowParentCampaigns'] = "Dangos ymgyrchoedd rhiant";
$GLOBALS['strHideParentCampaigns'] = "Cuddio ymgyrchoedd rhiant";
$GLOBALS['strHideInactiveBanners'] = "Cuddio baneri anweithredol";
$GLOBALS['strInactiveBannersHidden'] = "baner(i) anweithredol wedi cuddio";
$GLOBALS['strWarningMissing'] = "Rhybudd, y canlynol o bosib ar goll";
$GLOBALS['strWarningMissingClosing'] = " closing tag \">\"";
$GLOBALS['strWarningMissingOpening'] = " opening tag \"<\"";
$GLOBALS['strSubmitAnyway'] = "Argymell Beth Bynnag";

// Banner Preferences
$GLOBALS['strTypeSqlAllow'] = "Caniatáu Baneri Lleol SQL";
$GLOBALS['strTypeWebAllow'] = "Caniatáu Baneri Lleol Gwe-weinydd";
$GLOBALS['strTypeUrlAllow'] = "Caniatáu Baneri Allanol";
$GLOBALS['strTypeHtmlAllow'] = "Caniatáu Baneri HTML";
$GLOBALS['strTypeTxtAllow'] = "Caniatáu Hysbysebion Testun";

// Banner (Properties)
$GLOBALS['strChooseBanner'] = "Dewiswch math y baner";
$GLOBALS['strUploadOrKeep'] = "Ydych chi am gadw eich <br />llun presennol, neu ydych chi am <br />lanlwytho un arall?";
$GLOBALS['strNewBannerFile'] = "Dewiswch y llun yr ydych <br />am ei ddefnyddio ar gyfer y faner<br /><br />";
$GLOBALS['strNewBannerFileAlt'] = "Dewiswch y llun wrth gefn yr ydych <br />am ei ddefnyddio rhag ofn <br />nad yw'r porwr yn cefnogi cyfryngau cyfoethog<br />";
$GLOBALS['strNewBannerURL'] = "URL Llun (cynnwys. http://)";
$GLOBALS['strURL'] = "URL Gwefan (cynnwys. http://)";
$GLOBALS['strKeyword'] = "Allweddeiriau";
$GLOBALS['strTextBelow'] = "Testun dan y llun";
$GLOBALS['strWeight'] = "Pwysau";
$GLOBALS['strAlt'] = "Testun Alt";
$GLOBALS['strStatusText'] = "Testun statws";
$GLOBALS['strBannerWeight'] = "Pwysau baner";
$GLOBALS['strAdserverTypeGeneric'] = "Baner HTML Generig";
$GLOBALS['strGenericOutputAdServer'] = "Generig";

// Banner (advanced)

// Display Delviery Rules
$GLOBALS['strModifyBannerAcl'] = "Dewisiadau Trosglwyddiad";
$GLOBALS['strACL'] = "Dewisiadau Trosglwyddiad";
$GLOBALS['strEqualTo'] = "yn hafal i";
$GLOBALS['strDifferentFrom'] = "yn wahanol i";
$GLOBALS['strLaterThan'] = "yn hwyrach na";
$GLOBALS['strLaterThanOrEqual'] = "yn hwyrach na neu yn hafal i";
$GLOBALS['strEarlierThan'] = "yn gynharach na";
$GLOBALS['strEarlierThanOrEqual'] = "yn gynharach na neu yn hafal i";
$GLOBALS['strGreaterThan'] = "yn fwy na";
$GLOBALS['strLessThan'] = "yn llai na";
$GLOBALS['strAND'] = "A";                          // logical operator
$GLOBALS['strOR'] = "NEU";                         // logical operator
$GLOBALS['strOnlyDisplayWhen'] = "Dangos y faner yma yn unig pan:";
$GLOBALS['strWeekDays'] = "Dyddiau o'r wythnos";
$GLOBALS['strTime'] = "Amser";
$GLOBALS['strSource'] = "Ffynhonnell";

$GLOBALS['strDeliveryCappingReset'] = "Ailosod rhifydd golwg ar ôl:";
$GLOBALS['strDeliveryCappingTotal'] = "mewn cyfanswm";
$GLOBALS['strDeliveryCappingSession'] = "y sesiwn ";

if (!isset($GLOBALS['strCappingBanner'])) {
    $GLOBALS['strCappingBanner'] = [];
}
$GLOBALS['strCappingBanner']['limit'] = "Cyfyngu golygon baner i:";

if (!isset($GLOBALS['strCappingCampaign'])) {
    $GLOBALS['strCappingCampaign'] = [];
}
$GLOBALS['strCappingCampaign']['limit'] = "Cyfyngu golygon ymgyrch i:";

if (!isset($GLOBALS['strCappingZone'])) {
    $GLOBALS['strCappingZone'] = [];
}
$GLOBALS['strCappingZone']['limit'] = "Cyfyngu golygon ardal i:";

// Website
$GLOBALS['strAffiliate'] = "Gwefan";
$GLOBALS['strAffiliates'] = "Gwefannau";
$GLOBALS['strAffiliatesAndZones'] = "Gwefannau ac Ardaloedd";
$GLOBALS['strAddNewAffiliate'] = "Ychwanegu gwefan newydd";
$GLOBALS['strAffiliateProperties'] = "Priodweddau Gwefan";
$GLOBALS['strNoAffiliates'] = "Nid oes unrhyw wefan wedi cael ei ddiffinio hyd yma. I greu ardal, <a href='affiliate-edit.php'>ychwanegwch wefan newydd</a> yn gyntaf.";
$GLOBALS['strConfirmDeleteAffiliate'] = "Ydych chi wir am ddileu'r wefan yma?";
$GLOBALS['strConfirmDeleteAffiliates'] = "Ydych chi wir am ddileu'r wefan yma?";
$GLOBALS['strInactiveAffiliatesHidden'] = "gwefan(nau) anweithredol wedi cuddio";
$GLOBALS['strShowParentAffiliates'] = "Dangos gwefannau rhiant";
$GLOBALS['strHideParentAffiliates'] = "Cuddio gwefannau rhiant";

// Website (properties)
$GLOBALS['strWebsite'] = "Gwefan";
$GLOBALS['strAllowAffiliateModifyZones'] = "Caniatáu i'r defnyddiwr newid ei ardaloedd ei hunan";
$GLOBALS['strAllowAffiliateLinkBanners'] = "Caniatáu i'r defnyddiwr gysylltu baneri i'w ardaloedd ei hunan";
$GLOBALS['strAllowAffiliateAddZone'] = "Caniatáu i'r defnyddiwr ddiffinio ardaloedd newydd";
$GLOBALS['strAllowAffiliateDeleteZone'] = "Caniatáu i'r defnyddiwr ddileu ardaloedd presennol";
$GLOBALS['strAllowAffiliateGenerateCode'] = "Caniatáu i'r defnyddiwr gynhyrchu cod actifadu ei hunan";

// Website (properties - payment information)
$GLOBALS['strPostcode'] = "Cod Post";
$GLOBALS['strCountry'] = "Gwlad";

// Website (properties - other information)
$GLOBALS['strWebsiteZones'] = "Gwefannau ac Ardaloedd";

// Zone
$GLOBALS['strZone'] = "Ardal";
$GLOBALS['strZones'] = "Ardaloedd";
$GLOBALS['strAddNewZone'] = "Ychwanegu ardal newydd";
$GLOBALS['strAddNewZone_Key'] = "Ychwanegu ardal <u>n</u>ewydd";
$GLOBALS['strZoneToWebsite'] = "Pob gwefan";
$GLOBALS['strLinkedZones'] = "Ardaloedd cysylltiedig";
$GLOBALS['strZoneProperties'] = "Priodweddau Ardal";
$GLOBALS['strZoneHistory'] = "Hanes Ardal";
$GLOBALS['strNoZonesAddWebsite'] = "Nid oes unrhyw wefan wedi cael ei ddiffinio hyd yma. I greu ardal, <a href='affiliate-edit.php'>ychwanegwch wefan newydd</a> yn gyntaf.";
$GLOBALS['strConfirmDeleteZone'] = "Ydych chi wir am ddileu yr ardal yma?";
$GLOBALS['strConfirmDeleteZones'] = "Ydych chi wir am ddileu yr ardal yma?";
$GLOBALS['strZoneType'] = "Math ardal";
$GLOBALS['strBannerButtonRectangle'] = "Baner, Botwm neu Betryal";
$GLOBALS['strInterstitial'] = "DHTML Interstitaidd neu Arnawf";
$GLOBALS['strPopup'] = "Naidlen";
$GLOBALS['strTextAdZone'] = "Hysbyseb Testun";
$GLOBALS['strEmailAdZone'] = "Ardal Ebost/Cylchlythyr";
$GLOBALS['strShowMatchingBanners'] = "Dangos baneri sy'n cydweddu";
$GLOBALS['strHideMatchingBanners'] = "Cuddio baneri sy'n cydweddu";
$GLOBALS['strBannerLinkedAds'] = "Baneri sy'n gysylltiedig i'r ardal";
$GLOBALS['strCampaignLinkedAds'] = "Ymgyrchoedd sy'n gysylltiedig i'r ardal";
$GLOBALS['strInactiveZonesHidden'] = "ardal(oedd) anweithredol wedi cuddio";
$GLOBALS['strWarnChangeZoneType'] = "Bydd newid math yr ardal i testun neu ebost yn dad-gysylltu pob baner/ymgyrch oherwydd cyfyngderau'r mathau yma o ardaloedd
<ul>
<li>Gall ardaloedd testun gysylltu i hysbysebion testun yn unig</li>
<li>Gall ymgyrchoedd ardal ebost ddim ond gael un faner weithredol ar y tro</li>
</ul>";
$GLOBALS['strWarnChangeZoneSize'] = 'Bydd newid maint yr ardal yn dad-gysylltu unrhyw faneri sydd ddim o\'r maint newydd, ac yn ychwanegu unrhyw faneri o ymgyrchoedd cysylltiedig sydd o\'r maint newydd';


// Advanced zone settings
$GLOBALS['strAdvanced'] = "Uwch";
$GLOBALS['strChainSettings'] = "Gosodiadau cadwyn";
$GLOBALS['strZoneNoDelivery'] = "Os na ellir trosglwyddo unrhyw <br />faneri o'r ardal hon, ceisiwch...";
$GLOBALS['strZoneStopDelivery'] = "Atal trosglwyddo a peidio dangos baner";
$GLOBALS['strZoneOtherZone'] = "Arddangos yr ardal dewisedig yn lle";
$GLOBALS['strZoneAppend'] = "Atodi y cod HTML canlynol i faneri sy'n cael eu harddangos gan yr ardal hon bob tro";
$GLOBALS['strAppendSettings'] = "Gosodiadau Atodi a Rhagddodi";
$GLOBALS['strZonePrependHTML'] = "Rhagddodi y cod HTML i hysbysebion testun sy'n cael eu harddangos gan yr ardal hon bob tro";
$GLOBALS['strZoneAppendNoBanner'] = "Atodi hyd yn oed os na drosglwyddir baner";
$GLOBALS['strZoneAppendHTMLCode'] = "Cod HTML";
$GLOBALS['strZoneAppendZoneSelection'] = "Naidlen neu interstitaidd";

// Zone probability
$GLOBALS['strZoneProbListChain'] = "Mae'r holl faneri sydd wedi'u cysylltu i'r ardal dewisedig yn anweithredol ar hyn o bryd. <br />Dyma'r gadwyn ardal a fydd yn cael ei ddilyn:";
$GLOBALS['strZoneProbNullPri'] = "Nid oes unrhyw faneri gweithredol wedi'u cysylltu i'r ardal hon.";
$GLOBALS['strZoneProbListChainLoop'] = "Byddai dilyn y gadwyn ardal yn achosi dolen gron. Mae trosglwyddo i'r ardal hon wedi ei atal.";

// Linked banners/campaigns/trackers
$GLOBALS['strSelectZoneType'] = "Dewiswch beth i gysylltu i'r ardal hon";
$GLOBALS['strLinkedBanners'] = "Cysylltu baneri unigol";
$GLOBALS['strCampaignDefaults'] = "Cysylltu baneri wrth yr ymgyrch rhiant";
$GLOBALS['strLinkedCategories'] = "Cysylltu baneri wrth y categori";
$GLOBALS['strRawQueryString'] = "Allweddair";
$GLOBALS['strIncludedBanners'] = "Baneri Cysylltiedig";
$GLOBALS['strMatchingBanners'] = "{count} baner sy'n cydweddu";
$GLOBALS['strNoCampaignsToLink'] = "Nid oes unrhyw ymgyrch ar gael y gellir ei gysylltu i'r ardal hon";
$GLOBALS['strNoTrackersToLink'] = "Nid oes unrhyw draciwr ar gael y gellir ei gysylltu i'r ymgyrch hon";
$GLOBALS['strNoZonesToLinkToCampaign'] = "Nid oes unrhyw ardal ar gael y gellir cysylltu'r ymgyrch â hi";
$GLOBALS['strSelectBannerToLink'] = "Dewiswch y faner yr hoffech chi gysylltu â'r ardal hon:";
$GLOBALS['strSelectCampaignToLink'] = "Dewiswch yr ymgyrch yr hoffech chi gysylltu â'r ardal hon:";
$GLOBALS['strSelectAdvertiser'] = "Dewiswch Hysbysebwr";
$GLOBALS['strSelectPlacement'] = "Dewiswch Ymgyrch";
$GLOBALS['strSelectAd'] = "Dewiswch Faner";
$GLOBALS['strStatusPending'] = "Dan Ystyriaeth";
$GLOBALS['strStatusApproved'] = "Cymeradwywyd ";
$GLOBALS['strStatusDisapproved'] = "Anghymeradwywyd";
$GLOBALS['strStatusDuplicate'] = "Dyblygu";
$GLOBALS['strStatusOnHold'] = "Ar Aros";
$GLOBALS['strStatusIgnore'] = "Anwybyddu";
$GLOBALS['strConnectionType'] = "Math";
$GLOBALS['strConnTypeSale'] = "Gwerthiant";
$GLOBALS['strConnTypeLead'] = "Blaenydd";
$GLOBALS['strConnTypeSignUp'] = "Cofrestru";
$GLOBALS['strShortcutEditStatuses'] = "Golygu statysau";
$GLOBALS['strShortcutShowStatuses'] = "Dangos statysau";

// Statistics
$GLOBALS['strStats'] = "Ystadegau";
$GLOBALS['strNoStats'] = "Nid oes unrhyw ystadegau ar gael ar hyn o bryd";
$GLOBALS['strNoStatsForPeriod'] = "Nid oes unrhyw ystadegau ar gael ar gyfer cyfnod %s i %s ar hyn o bryd";
$GLOBALS['strTotalThisPeriod'] = "Cyfanswm ar gyfer cyfnod";
$GLOBALS['strPublisherDistribution'] = "Dosbarthiad gwefan";
$GLOBALS['strCampaignDistribution'] = "Dosbarthiad Ymgyrch";
$GLOBALS['strViewBreakdown'] = "Golwg gan";
$GLOBALS['strBreakdownByDay'] = "Diwrnod";
$GLOBALS['strBreakdownByWeek'] = "Wythnos";
$GLOBALS['strBreakdownByMonth'] = "Mis";
$GLOBALS['strBreakdownByDow'] = "Diwrnod yr wythnos";
$GLOBALS['strBreakdownByHour'] = "Awr";
$GLOBALS['strItemsPerPage'] = "Eitem y tudalen";
$GLOBALS['strShowGraphOfStatistics'] = "Dangos yr Ystadegau fel <u>G</u>raff";
$GLOBALS['strExportStatisticsToExcel'] = "Allforio'r Ystadegau i Excel";

// Expiration
$GLOBALS['strNoExpiration'] = "Dyddiad dod i ben heb ei osod";
$GLOBALS['strEstimated'] = "Dyddiad dod i ben amcangyfrifol";
$GLOBALS['strCampaignStop'] = "Hanes ymgyrch";

// Reports
$GLOBALS['strStartDate'] = "Dyddiad Cychwyn";
$GLOBALS['strEndDate'] = "Dyddiad Gorffen";

// Admin_UI_Fields
$GLOBALS['strAllAdvertisers'] = "Pob hysbysebwr";
$GLOBALS['strAnonAdvertisers'] = "Hysbysebwyr anhysbys";
$GLOBALS['strAllPublishers'] = "Pob gwefan";
$GLOBALS['strAnonPublishers'] = "Gwefannau anhysbys";
$GLOBALS['strAllAvailZones'] = "Pob ardal posib";

// Userlog
$GLOBALS['strUserLog'] = "Log Defnyddiwr";
$GLOBALS['strUserLogDetails'] = "Manylion log defnyddiwr";
$GLOBALS['strDeleteLog'] = "Dileu log";
$GLOBALS['strAction'] = "Gweithred";
$GLOBALS['strNoActionsLogged'] = "Dim gweithredoedd wedi'u logio";

// Code generation
$GLOBALS['strGenerateBannercode'] = "Dewis uniongyrchol";
$GLOBALS['strChooseInvocationType'] = "Dewiswch y math o actifadu baneri";
$GLOBALS['strGenerate'] = "Cynhyrchu";
$GLOBALS['strParameters'] = "Gosodiadau Tagiau";
$GLOBALS['strFrameSize'] = "Maint ffram";
$GLOBALS['strBannercode'] = "Codbaner";
$GLOBALS['strBackToTheList'] = "Mynd yn ôl i'r rhestr adroddiadau";

// Errors
$GLOBALS['strNoMatchesFound'] = "Methwyd darganfod cydweddiadau";
$GLOBALS['strErrorOccurred'] = "Bu gwall";
$GLOBALS['strErrorDBPlain'] = "Bu gwall tra'n cyrchu'r gronfa ddata";
$GLOBALS['strErrorDBSerious'] = "Datgelwyd problem ddifrifol gyda'r gronfa ddata";
$GLOBALS['strErrorDBContact'] = "Cysylltwch â gweinyddwr y gweinydd a'i hysbysu o'r broblem.";
$GLOBALS['strUnableToLinkBanner'] = "Methwyd cysylltu'r baner:";
$GLOBALS['strUnableToChangeZone'] = "Methwyd gweithredu'r newidiad oherwydd:";
$GLOBALS['strDatesConflict'] = "dyddiadau'n gwrthdaro gyda:";
$GLOBALS['strEmailNoDates'] = "Rhaid i ymgyrchoedd ardal ebost gael dyddiad cychwyn a gorffen";

//Validation

// Email
$GLOBALS['strSirMadam'] = "Syr/Madam";
$GLOBALS['strMailSubject'] = "Adroddiad Hysbysebwr";
$GLOBALS['strMailHeader'] = "Annwyl{contact},";
$GLOBALS['strMailBannerStats'] = "Isod byddwch yn darganfod ystadegau baner ar gyfer {clientname}:";
$GLOBALS['strMailBannerActivatedSubject'] = "Ymgyrch wedi ysgogi";
$GLOBALS['strMailBannerDeactivatedSubject'] = "Ymgyrch wedi dad-ysgogi";
$GLOBALS['strMailBannerActivated'] = "Mae eich ymgyrch a ddangosir isod wedi cael ei ysgogi achos
bod y dyddiad ysgogi ymgyrch wedi cael ei gyrraedd.";
$GLOBALS['strMailBannerDeactivated'] = "Mae eich ymgyrch a ddangosir isod wedi cael ei ddad-ysgogi achos";
$GLOBALS['strMailFooter'] = "Cofion,
{adminfullname}";
$GLOBALS['strClientDeactivated'] = "Nid yw'r ymgyrch yn weithredol ar hyn o bryd oherwydd";
$GLOBALS['strBeforeActivate'] = "nad yw'r dyddiad ysgogi wedi cyrraedd eto";
$GLOBALS['strAfterExpire'] = "nad yw'r dyddiad gorffen weddi cyrraedd";
$GLOBALS['strNoMoreImpressions'] = "nad oes Argraffiadau yn weddill";
$GLOBALS['strNoMoreClicks'] = "nad oes Cliciau yn weddill";
$GLOBALS['strNoMoreConversions'] = "nad oes gwerthiannau yn weddill";
$GLOBALS['strWeightIsNull'] = "bod y pwysau wedi ei osod i sero";
$GLOBALS['strNoViewLoggedInInterval'] = "Ni logiwyd unrhyw Argraffiadau yn ystod cyfnod yr adroddiad hwn";
$GLOBALS['strNoClickLoggedInInterval'] = "Ni logiwyd unrhyw Gliciau yn ystod cyfnod yr adroddiad hwn";
$GLOBALS['strNoConversionLoggedInInterval'] = "Ni logiwyd unrhyw Drawsnewidiadau yn ystod cyfnod yr adroddiad hwn";
$GLOBALS['strMailReportPeriod'] = "Mae'r adroddiad hwn yn cynnwys ystadegau o {startdate} hyd at {enddate}.";
$GLOBALS['strMailReportPeriodAll'] = "Mae'r adroddiad hwn yn cynnwys yr holl ystadegau hyd at {enddate}.";
$GLOBALS['strNoStatsForCampaign'] = "Nid oes ystadegau ar gael ar gyfer yr ymgyrch hon";
$GLOBALS['strImpendingCampaignExpiry'] = "Diwedd cyfnod yr ymgyrch yn agos";
$GLOBALS['strYourCampaign'] = "Eich ymgyrch";
$GLOBALS['strTheCampiaignBelongingTo'] = "Yr ymgyrch sy'n perthyn i";
$GLOBALS['strImpendingCampaignExpiryDateBody'] = "Mae {clientname} a ddangosir isod yn dod i ben ar {date}.";
$GLOBALS['strImpendingCampaignExpiryImpsBody'] = "Mae gan {clientname} a ddangosir isod lai na {limit} argraffiad yn weddill.";

// Priority
$GLOBALS['strPriority'] = "Blaenoriaeth";
$GLOBALS['strSourceEdit'] = "Golygu Ffynonellau";

// Preferences
$GLOBALS['strPreferences'] = "Dewisiadau";

// Long names
$GLOBALS['strERPM'] = "CPM";
$GLOBALS['strERPC'] = "CPC";
$GLOBALS['strERPS'] = "CPM";
$GLOBALS['strEIPM'] = "CPM";
$GLOBALS['strEIPC'] = "CPC";
$GLOBALS['strEIPS'] = "CPM";
$GLOBALS['strECPM'] = "CPM";
$GLOBALS['strECPC'] = "CPC";
$GLOBALS['strECPS'] = "CPM";
$GLOBALS['strImpressionSR'] = "Argraffiadau";

// Short names
$GLOBALS['strERPM_short'] = "CPM";
$GLOBALS['strERPC_short'] = "CPC";
$GLOBALS['strERPS_short'] = "CPM";
$GLOBALS['strEIPM_short'] = "CPM";
$GLOBALS['strEIPC_short'] = "CPC";
$GLOBALS['strEIPS_short'] = "CPM";
$GLOBALS['strECPM_short'] = "CPM";
$GLOBALS['strECPC_short'] = "CPC";
$GLOBALS['strECPS_short'] = "CPM";
$GLOBALS['strClicks_short'] = "Cliciau";

// Global Settings
$GLOBALS['strGlobalSettings'] = "Gosodiadau Cyffredinol";
$GLOBALS['strGeneralSettings'] = "Gosodiadau Cyffredinol";
$GLOBALS['strMainSettings'] = "Prif Osodiadau";

// Product Updates
$GLOBALS['strProductUpdates'] = "Diweddariadau Cynnyrch";

// Agency
$GLOBALS['strAddAgency_Key'] = "Ychwanegu ardal <u>n</u>ewydd";
$GLOBALS['strNoAgencies'] = "Nid oes unrhyw gyfrifon wedi eu diffinio eto";
$GLOBALS['strConfirmDeleteAgency'] = "Ydych chi wir am ddileu y cyfrif yma?";
$GLOBALS['strInactiveAgenciesHidden'] = "cyfrif(on) anweithredol wedi cuddio";
$GLOBALS['strAgencyStatusInactive'] = "gweithredol";

// Channels
$GLOBALS['strChannelToWebsite'] = "Pob gwefan";
$GLOBALS['strChannelLimitations'] = "Dewisiadau Trosglwyddiad";

// Tracker Variables
$GLOBALS['strVariableDescription'] = "Disgrifiad";
$GLOBALS['strGeneric'] = "Generig";
$GLOBALS['strTrackerType'] = "Enw Traciwr";

// Password recovery

// Password recovery - Default


// Password recovery - Welcome email

// Password recovery - Hash update

// Password reset warning

// Audit

// Widget - Audit

// Widget - Campaign

$GLOBALS['strCampaignAuditTrailSetup'] = "Ysgogi Trywydd Archwilio er mwyn cychwyn gweld Ymgyrchoedd";


//confirmation messages










// Report error messages

/* ------------------------------------------------------- */
/* HTML5                                                   */
/* ------------------------------------------------------- */

/* ------------------------------------------------------- */
/* Password strength                                       */
/* ------------------------------------------------------- */


if (!isset($GLOBALS['strPasswordScore'])) {
    $GLOBALS['strPasswordScore'] = [];
}



/* ------------------------------------------------------- */
/* Keyboard shortcut assignments                           */
/* ------------------------------------------------------- */

// Reserved keys
// Do not change these unless absolutely needed

// Other keys
// Please make sure you underline the key you
// used in the string in default.lang.php
